The highest tagged major version is
v13.
package
Version:
v12.41.0+incompatible
Opens a new window with list of versions in this module.
Published: Feb 8, 2022
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package secstr provides methods and structs for working with protected (secure) strings
type String struct {
Data []byte
}
String contains protected data
func NewSecureString(data interface{}) (*String, error)
NewSecureString creates new secure string
passwd := "MySuppaPassword12345"
ss, err := NewSecureString(&passwd)
if err != nil {
panic(err)
}
fmt.Printf("Password: %s", string(ss.Data))
IsEmpty returns false if string is empty
Source Files
¶
Click to show internal directories.
Click to hide internal directories.