kernel

package
v14.1.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package kernel provides methods for collecting information from OS kernel

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Collect

func Collect(params ...string) []support.KernelParam

Collect returns kernel parameters matching the given names or prefix patterns. Patterns ending with "*" are treated as prefix globs (e.g. "vm.*" matches all vm parameters). Returns nil if no params match or if the kernel cannot be queried.

Types

This section is empty.

Jump to