Documentation
¶
Overview ¶
Package kernel provides methods for collecting information from OS kernel
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Collect ¶
func Collect(params ...string) []support.KernelParam
Collect returns kernel parameters matching the given names or prefix patterns. Patterns ending with "*" are treated as prefix globs (e.g. "vm.*" matches all vm parameters). Returns nil if no params match or if the kernel cannot be queried.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.